(define-package "haskell-mode" "17.2-git" "A Haskell editing mode"
  '((emacs "25.1"))
  :url "https://github.com/haskell/haskell-mode"
  :keywords '("haskell" "cabal" "ghc" "repl"))
;; Local Variables:
;; no-byte-compile: t
;; End:
